==> nextcloud-app-tasks-0.14.5-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/tasks/l10n/th.js <==
OC.L10N.register(
    "tasks",
    {
    "Important" : "สำคัญ",
    "Today" : "วันนี้",
    "Week" : "สัปดาห์",
    "All" : "ทั้งหมด",
    "Current" : "ปัจจุบัน",
    "Completed" : "เสร็จสมบูรณ์",
    "Tasks" : "งาน",
    "Visibility of Smart Collections" : "การแสดงผลของสมาร์ทคอลเลกชัน",
    "Hidden" : "ซ่อน",
    "Visible" : "มองเห็นได้",
    "Automatic" : "อัตโนมัติ",
    "Share with users or groups" : "แชร์กับผู้ใช้หรือกลุ่ม",
    "Can edit" : "Can edit",
    "Edit" : "แก้ไข",
    "Export" : "ส่งออก",
    "Delete" : "ลบ",
    "Unshare" : "ยกเลิกการแชร์",
    "Save" : "บันทึก",
    "An empty name is not allowed." : "ชื่อห้ามปล่อยว่าง",
    "Name" : "ชื่อ",
    "Deleted" : "ลบแล้ว",
    "Restore" : "คืนค่า",
    "Delete permanently" : "ลบแบบถาวร",
    "Empty trash bin" : "ล้างข้อมูลในถังขยะ",
    "Change sort order" : "เปลี่ยนการเรียงลำดับ",
    "Start date" : "วันที่เริ่มต้น",
    "Due date" : "วันที่ครบกำหนด",
    "Priority" : "ลำดับความสำคัญ",
    "Alphabetically" : "เรียงตามตัวอักษร",
    "Manually" : "ทำด้วยตนเอง",
    "Cancel" : "ยกเลิก",
    "Close" : "ปิด",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n งานเสร็จสมบูรณ์"],
    "Tomorrow" : "วันพรุ่งนี้",
    "New List" : "รายชื่อใหม่",
    "Details" : "รายละเอียด",
    "Notes" : "โน้ต",
    "Reminders" : "การแจ้งเตือน",
    "Repeat" : "ทำซ้ำ",
    "When shared show full event" : "เมื่อแชร์จะแสดงกิจกรรมทั้งหมด",
    "When shared show only busy" : "เมื่อแชร์จะแสดงเฉพาะไม่ว่าง",
    "When shared hide this event" : "เมื่อแชร์จะซ่อนกิจกรรมนี้",
    "Task not found!" : "ไม่พบงาน!",
    "Set start date" : "วันที่เริ่มต้นการตั้งค่า",
    "Set due date" : "ระบุวันครบกำหนด",
    "An error occurred" : "เกิดข้อผิดพลาด"
},
"nplurals=1; plural=0;");

==> nextcloud-app-tasks-0.15.0-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/tasks/l10n/th.js <==
OC.L10N.register(
    "tasks",
    {
    "Important" : "สำคัญ",
    "Today" : "วันนี้",
    "Week" : "สัปดาห์",
    "All" : "ทั้งหมด",
    "Current" : "ปัจจุบัน",
    "Completed" : "เสร็จแล้ว",
    "Tasks" : "งาน",
    "Visibility of Smart Collections" : "การมองเห็นของสมาร์ทคอลเลกชัน",
    "Hidden" : "ซ่อนอยู่",
    "Visible" : "มองเห็นได้",
    "Automatic" : "อัตโนมัติ",
    "Share with users or groups" : "แชร์กับผู้ใช้หรือกลุ่ม",
    "Can edit" : "สามารถแก้ไข",
    "Edit" : "แก้ไข",
    "Export" : "ส่งออก",
    "Delete" : "ลบ",
    "Unshare" : "เลิกแชร์",
    "An empty name is not allowed." : "ชื่อห้ามปล่อยว่าง",
    "Name" : "ชื่อ",
    "Deleted" : "ลบแล้ว",
    "Restore" : "คืนค่า",
    "Delete permanently" : "ลบแบบถาวร",
    "Empty trash bin" : "ล้างข้อมูลในถังขยะ",
    "Change sort order" : "เปลี่ยนการเรียงลำดับ",
    "Start date" : "วันที่เริ่มต้น",
    "Due date" : "วันที่ครบกำหนด",
    "Priority" : "ลำดับความสำคัญ",
    "Alphabetically" : "เรียงตามตัวอักษร",
    "Manually" : "ด้วยตนเอง",
    "Cancel" : "ยกเลิก",
    "Close" : "ปิด",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n งานที่เสร็จแล้ว"],
    "Tomorrow" : "พรุ่งนี้",
    "Details" : "รายละเอียด",
    "Notes" : "โน้ต",
    "Reminders" : "การแจ้งเตือน",
    "Repeat" : "ทำซ้ำ",
    "When shared show full event" : "เมื่อแชร์จะแสดงกิจกรรมเต็ม",
    "When shared show only busy" : "เมื่อแชร์จะแสดงเฉพาะไม่ว่าง",
    "When shared hide this event" : "เมื่อแชร์จะซ่อนกิจกรรมนี้",
    "Task not found!" : "ไม่พบงาน!",
    "Set start date" : "ตั้งวันที่เริ่มต้น",
    "Set due date" : "ตั้งวันที่ครบกำหนด",
    "An error occurred" : "เกิดข้อผิดพลาด"
},
"nplurals=1; plural=0;");
